The following are all valid section title adornment characters
according to
https://docutils.sourceforge.io/docs/ref/rst/restructuredtext.html#sections.


Section
!!!!!!!


Section
"""""""


Section
#######


Section
$$$$$$$


Section
%%%%%%%


Section
&&&&&&&


Section
'''''''


Section
(((((((


Section
)))))))


Section
*******


Section
+++++++


Section
,,,,,,,


Section
-------


Section
.......


Section
///////


Section
:::::::


Section
;;;;;;;


Section
<<<<<<<


Section
=======


Section
>>>>>>>


Section
???????


Section
@@@@@@@


Section
[[[[[[[


Section
\\\\\\\


Section
]]]]]]]


Section
^^^^^^^


Section
_______


Section
```````


Section
{{{{{{{


Section
|||||||


Section
}}}}}}}


Section
~~~~~~~
